Penalty Scaling Function for parametric penalty weights
penalty_scaler(lag, m, r, plot = TRUE, log = TRUE)a vector of lags for which to calculate the penalty function
a vector of seasonality modes
a vector of dim (m + 1) for the factor penalties on c(m, time)
logical; whether to plot the penalty function
logical; whether to return the log of the penalty function